<?php

declare(strict_types=1);

namespace Dedi\SyliusContactPlugin\Mailer;

use Dedi\SyliusContactPlugin\Entity\AttachmentInterface;
use Dedi\SyliusContactPlugin\Entity\ContactFormMessageInterface;
use Sylius\Component\Channel\Context\ChannelContextInterface;
use Sylius\Component\Locale\Context\LocaleContextInterface;
use Sylius\Component\Mailer\Sender\SenderInterface;

class ContactRequestMailer implements ContactRequestMailerInterface
{
    private SenderInterface $mailer;

    private LocaleContextInterface $localeContext;

    private ChannelContextInterface $channelContext;

    public function __construct(
        SenderInterface $mailer,
        LocaleContextInterface $localeContext,
        ChannelContextInterface $channelContext
    ) {
        $this->mailer = $mailer;
        $this->localeContext = $localeContext;
        $this->channelContext = $channelContext;
    }

    public function send(
        ContactFormMessageInterface $message
    ): void {
        $this->mailer->send(self::MAIL_CODE, [$message->getSubject()->getRecipientEmail()], [
            'contactMessage' => $message,
            'localeCode' => $this->localeContext->getLocaleCode(),
            'channel' => $this->channelContext->getChannel(),
        ], array_map(function (AttachmentInterface $attachment) {
            return $attachment->getPath();
        }, $message->getAttachments()->toArray()));
    }
}
